==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/java/org/gnu/gtk/ResizeMode.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.javagnome.Enum;

public class ResizeMode extends Enum 
{
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    static final private int _PARENT = 0;
    static final public org.gnu.gtk.ResizeMode PARENT = new org.gnu.gtk.ResizeMode (_PARENT);
    static final private int _QUEUE = 1;
    static final public org.gnu.gtk.ResizeMode QUEUE = new org.gnu.gtk.ResizeMode (_QUEUE);
    static final private int _IMMEDIATE = 2;
    static final public org.gnu.gtk.ResizeMode IMMEDIATE = new org.gnu.gtk.ResizeMode (_IMMEDIATE);
    static final private org.gnu.gtk.ResizeMode[] theInterned = new org.gnu.gtk.ResizeMode[] 
    {
        PARENT, QUEUE, IMMEDIATE 
    }

;
    static private java.util.Hashtable theInternedExtras;
    static final private org.gnu.gtk.ResizeMode theSacrificialOne = new org.gnu.gtk.ResizeMode (0);
    static public org.gnu.gtk.ResizeMode intern (int value) 
    {
        if (value < theInterned.length) 
        {
            return theInterned[value];
        }
        theSacrificialOne.value_ = value;
        if (theInternedExtras == null) 
        {
            theInternedExtras = new java.util.Hashtable();
        }
        org.gnu.gtk.ResizeMode already = (org.gnu.gtk.ResizeMode) theInternedExtras.get (
            theSacrificialOne);
        if (already == null) 
        {
            already = new org.gnu.gtk.ResizeMode(value);
            theInternedExtras.put(already, already);
        }
        return already;
    }

    private ResizeMode (int value) 
    {
        value_ = value;
    }

    public org.gnu.gtk.ResizeMode or (org.gnu.gtk.ResizeMode other) 
    {
        return intern(value_ | other.value_);
    }

    public org.gnu.gtk.ResizeMode and (org.gnu.gtk.ResizeMode other) 
    {
        return intern(value_ & other.value_);
    }

    public org.gnu.gtk.ResizeMode xor (org.gnu.gtk.ResizeMode other) 
    {
        return intern(value_ ^ other.value_);
    }

    public boolean test (org.gnu.gtk.ResizeMode other) 
    {
        return (value_ & other.value_) == other.value_;
    }

    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}

==> libgtk-java-2.8.1.tar.bz2: libgtk-java-2.8.1/src/java/org/gnu/gtk/ResizeMode.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.Enum;

public class ResizeMode extends Enum 
{
    /****************************************
     * BEGINNING OF GENERATED CODE
     ****************************************/
    static final private int _PARENT = 0;
    static final public org.gnu.gtk.ResizeMode PARENT = new org.gnu.gtk.ResizeMode (_PARENT);
    static final private int _QUEUE = 1;
    static final public org.gnu.gtk.ResizeMode QUEUE = new org.gnu.gtk.ResizeMode (_QUEUE);
    static final private int _IMMEDIATE = 2;
    static final public org.gnu.gtk.ResizeMode IMMEDIATE = new org.gnu.gtk.ResizeMode (_IMMEDIATE);
    static final private org.gnu.gtk.ResizeMode[] theInterned = new org.gnu.gtk.ResizeMode[] 
    {
        PARENT, QUEUE, IMMEDIATE 
    }

;
    static private java.util.Hashtable theInternedExtras;
    static final private org.gnu.gtk.ResizeMode theSacrificialOne = new org.gnu.gtk.ResizeMode (0);
    static public org.gnu.gtk.ResizeMode intern (int value) 
    {
        if (value < theInterned.length) 
        {
            return theInterned[value];
        }
        theSacrificialOne.value_ = value;
        if (theInternedExtras == null) 
        {
            theInternedExtras = new java.util.Hashtable();
        }
        org.gnu.gtk.ResizeMode already = (org.gnu.gtk.ResizeMode) theInternedExtras.get (
            theSacrificialOne);
        if (already == null) 
        {
            already = new org.gnu.gtk.ResizeMode(value);
            theInternedExtras.put(already, already);
        }
        return already;
    }

    private ResizeMode (int value) 
    {
        value_ = value;
    }

    public org.gnu.gtk.ResizeMode or (org.gnu.gtk.ResizeMode other) 
    {
        return intern(value_ | other.value_);
    }

    public org.gnu.gtk.ResizeMode and (org.gnu.gtk.ResizeMode other) 
    {
        return intern(value_ & other.value_);
    }

    public org.gnu.gtk.ResizeMode xor (org.gnu.gtk.ResizeMode other) 
    {
        return intern(value_ ^ other.value_);
    }

    public boolean test (org.gnu.gtk.ResizeMode other) 
    {
        return (value_ & other.value_) == other.value_;
    }

    /****************************************
     * END OF GENERATED CODE
     ****************************************/
}
